@@ -50,12 +50,12 @@ class NtWriter:
 			if fname.endswith (".gz"):
 				# can't open temp file to gzip, see http://www.enricozini.org/2011/cazzeggio/python-gzip/
 				self.tmpname = tempfile.mktemp(prefix = "ntwriter-", suffix = ".tmp", dir = parentdir)
-				fh = gzip.open (self.tmpname, "w")
+				fh = gzip.open (self.tmpname, "wb")
 			else:
 				# this is the proper, race-less way to atomically create and open a temporary file
 				# Unfortunately it only works for non-gz files
 				(handle, self.tmpname) = tempfile.mkstemp(dir = parentdir)
-				fh = os.fdopen(handle, "w")
+				fh = os.fdopen(handle, "wb")
 				#fh = open (fname, "w")
 			
 		print ("Using temp file: " + self.tmpname)
